@@ -7,6 +7,7 @@ import os
 import sys
 import math
 import time
+import tqdm
 import argparse
 
 import numpy as np
@@ -140,17 +141,17 @@ class MaxiMask_inference(object):
         log.info(f"List of files to process: {file_list}")
 
         if len(file_list):
-
             os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"
             log.info("##### Beginning of possible Tensorflow logs")
             import tensorflow as tf
-
             tf_model = tf.saved_model.load(self.net_dir)
             log.info("##### End of Tensorflow logs")
             log.info(f"Using TensorFlow version {tf.__version__}")
+            gpu_devices = tf.config.list_logical_devices("GPU")
+            log.info(f"TensorFlow has created {len(gpu_devices)} logical GPU device(s)")
 
-            # process each file of file list
-            for file_name in file_list:
+            # process each file of file 
+            for file_name in tqdm.tqdm(file_list, desc="ALL FILES"):
                 log.info(f"Starting {file_name}")
                 self.process_file(file_name, tf_model)
                 log.info(f"{file_name} done")
@@ -165,41 +166,51 @@ class MaxiMask_inference(object):
         # make hdu tasks
         hdu_task_list = self.make_hdu_tasks(file_name)
 
-        # process each hdu
-        for hdu_idx, task, hdu_type, hdu_shape in hdu_task_list:
-            log.info(f"HDU {hdu_idx}: {task}")
+        # check that there is at least one HDU to process
+        at_least_one = False
+        for _, task, _, _ in hdu_task_list:
+            if task=="process":
+                at_least_one = True
 
-            # get raw predictions
-            hdu_preds, t = self.process_hdu(file_name, hdu_idx, task, tf_model)
-            if hdu_shape is not None:
-                log.info(
-                    f"Whole processing time (incl. preprocessing): {t:.2f}s, {np.prod(hdu_shape)/(t*1e06):.2f}MPix/s"
+        # if at least one HDU to be processed
+        if at_least_one:
+            # go through all all HDUs
+            for hdu_idx, task, hdu_type, hdu_shape in hdu_task_list:
+                log.info(f"HDU {hdu_idx}: {task}")
+
+                # get raw predictions
+                hdu_preds, t = self.process_hdu(file_name, hdu_idx, task, tf_model)
+                if hdu_shape is not None:
+                    log.info(
+                        f"Whole processing time (incl. preprocessing): {t:.2f}s, {np.prod(hdu_shape)/(t*1e06):.2f}MPix/s"
+                    )
+
+                # append the HDU
+                if hdu_type == "PrimaryHDU":
+                    hdu = fits.PrimaryHDU(hdu_preds)
+                elif hdu_type == "ImageHDU" or hdu_type == "CompImageHDU":
+                    hdu = fits.ImageHDU(hdu_preds)
+                self.fill_header(hdu)
+                final_file_hdu.append(hdu)
+
+            # write file
+            out_file_name = file_name
+            if ".fz" in out_file_name:
+                out_file_name = out_file_name.replace(".fz", "")
+            if ".gz" in file_name:
+                out_file_name = out_file_name.replace(".gz", "")
+            if "[" in out_file_name:
+                spec_hdu_idx = int(file_name.split("[")[1].split("]")[0])
+                out_file_name = out_file_name.split("[")[0].replace(
+                    ".fits", f".mask{spec_hdu_idx}.fits"
+                )
+                final_file_hdu.writeto(out_file_name, overwrite=True)
+            else:
+                final_file_hdu.writeto(
+                    out_file_name.replace(".fits", ".mask.fits"), overwrite=True
                 )
-
-            # append the HDU
-            if hdu_type == "PrimaryHDU":
-                hdu = fits.PrimaryHDU(hdu_preds)
-            elif hdu_type == "ImageHDU" or hdu_type == "CompImageHDU":
-                hdu = fits.ImageHDU(hdu_preds)
-            self.fill_header(hdu)
-            final_file_hdu.append(hdu)
-
-        # write file
-        out_file_name = file_name
-        if ".fz" in out_file_name:
-            out_file_name = out_file_name.replace(".fz", "")
-        if ".gz" in file_name:
-            out_file_name = out_file_name.replace(".gz", "")
-        if "[" in out_file_name:
-            spec_hdu_idx = int(file_name.split("[")[1].split("]")[0])
-            out_file_name = out_file_name.split("[")[0].replace(
-                ".fits", f".mask{spec_hdu_idx}.fits"
-            )
-            final_file_hdu.writeto(out_file_name, overwrite=True)
         else:
-            final_file_hdu.writeto(
-                out_file_name.replace(".fits", ".mask.fits"), overwrite=True
-            )
+            log.info(f"Skipping {file_name} because no HDU was found to be processed")
 
     def make_hdu_tasks(self, file_name):
         """Make the hdu task list for the given file_name"""
@@ -265,8 +276,9 @@ class MaxiMask_inference(object):
                 block_coord_list = self.get_block_coords(h, w)
 
                 # preprocessing
+                log.info("Preprocessing...")
                 hdu_data, t = utils.image_norm(hdu_data)
-                log.info(f"Preprocessing time: {t:.2f}s, {h*w/(t*1e06):.2f}MPix/s")
+                log.info(f"Preprocessing done in {t:.2f}s, {h*w/(t*1e06):.2f}MPix/s")
 
                 # process all the blocks by batches
                 # the process_batch method writes the predictions in preds by reference
@@ -277,7 +289,7 @@ class MaxiMask_inference(object):
                 else:
                     # several batches to process + one last possibly not full
                     nb_batch = nb_blocks // self.batch_size
-                    for b in range(nb_batch):
+                    for b in tqdm.tqdm(range(nb_batch), desc="INFERENCE: "):
                         batch_coord_list = block_coord_list[
                             b * self.batch_size : (b + 1) * self.batch_size
                         ]
@@ -456,20 +468,19 @@ def main():
 
     # optional parameters
     script_dir = os.path.dirname(os.path.abspath(__file__))
-    net_dir = os.path.join(
-        os.path.dirname(script_dir), "data/tensorflow_models/maximask"
-    )
-    config_dir = os.path.join(os.path.dirname(script_dir), "data/configs")
+    root_dir = os.path.dirname(os.path.dirname(script_dir))
+    net_dir = os.path.join(root_dir, "models/maximask")
+    config_dir = os.path.join(root_dir, "config/maximask")
     parser.add_argument(
         "--net_dir",
         type=str,
-        help="neural network graphs and weights directory. Default is </abs_path_to_scripts/../tensorflow_models/maximask>",
+        help="neural network graphs and weights directory. Default is </path_to_root/models/maximask>",
         default=net_dir,
     )
     parser.add_argument(
         "--config_dir",
         type=str,
-        help="configuration file directory. Default is </abs_path_to_script/../data/configs>",
+        help="configuration file directory. Default is </path_to_root/config/maximask>",
         default=config_dir,
     )
     parser.add_argument(
